==> openshift-model-4.13.0-sources.jar: annotations/io/fabric8/openshift/api/model/CustomFeatureGatesFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class CustomFeatureGatesFluentImpl<A extends CustomFeatureGatesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements CustomFeatureGatesFluent<A> {

    private List<String> disabled = new ArrayList<String>();
    private List<String> enabled = new ArrayList<String>();

    public CustomFeatureGatesFluentImpl() { 
    }


    public CustomFeatureGatesFluentImpl(CustomFeatureGates instance) { 
        this.withDisabled(instance.getDisabled()); 
        this.withEnabled(instance.getEnabled()); 
    }


    public A addToDisabled(int index,String item) {
        if (this.disabled == null) {this.disabled = new ArrayList<String>();}
        this.disabled.add(index, item);
        return (A)this;
    }

    public A setToDisabled(int index,String item) {
        if (this.disabled == null) {this.disabled = new ArrayList<String>();}
        this.disabled.set(index, item); return (A)this;
    }

    public A addToDisabled(String... items) {
        if (this.disabled == null) {this.disabled = new ArrayList<String>();}
        for (String item : items) {this.disabled.add(item);} return (A)this;
    }

    public A addAllToDisabled(Collection<String> items) {
        if (this.disabled == null) {this.disabled = new ArrayList<String>();}
        for (String item : items) {this.disabled.add(item);} return (A)this;
    }

    public A removeFromDisabled(String... items) {
        for (String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
    }

    public A removeAllFromDisabled(Collection<String> items) {
        for (String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
    }

    public List<String> getDisabled() {
        return this.disabled;
    }

    public String getDisabled(int index) {
        return this.disabled.get(index);
    }

    public String getFirstDisabled() {
        return this.disabled.get(0);
    }

    public String getLastDisabled() {
        return this.disabled.get(disabled.size() - 1);
    }

    public String getMatchingDisabled(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: disabled) { if(predicate.apply(item)){ return item;} } return null;
    }

    public Boolean hasMatchingDisabled(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: disabled) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withDisabled(List<String> disabled) {
        if (this.disabled != null) { _visitables.get("disabled").removeAll(this.disabled);}
        if (disabled != null) {this.disabled = new ArrayList<String>(); for (String item : disabled){this.addToDisabled(item);}} else { this.disabled = null;} return (A) this;
    }

    public A withDisabled(String... disabled) {
        if (this.disabled != null) {this.disabled.clear();}
        if (disabled != null) {for (String item :disabled){ this.addToDisabled(item);}} return (A) this;
    }

    public Boolean hasDisabled() {
        return disabled != null && !disabled.isEmpty();
    }

    public A addNewDisabled(String arg1) {
        return (A)addToDisabled(new String(arg1));
    }

    public A addNewDisabled(StringBuilder arg1) {
        return (A)addToDisabled(new String(arg1));
    }

    public A addNewDisabled(StringBuffer arg1) {
        return (A)addToDisabled(new String(arg1));
    }

    public A addToEnabled(int index,String item) {
        if (this.enabled == null) {this.enabled = new ArrayList<String>();}
        this.enabled.add(index, item);
        return (A)this;
    }

    public A setToEnabled(int index,String item) {
        if (this.enabled == null) {this.enabled = new ArrayList<String>();}
        this.enabled.set(index, item); return (A)this;
    }

    public A addToEnabled(String... items) {
        if (this.enabled == null) {this.enabled = new ArrayList<String>();}
        for (String item : items) {this.enabled.add(item);} return (A)this;
    }

    public A addAllToEnabled(Collection<String> items) {
        if (this.enabled == null) {this.enabled = new ArrayList<String>();}
        for (String item : items) {this.enabled.add(item);} return (A)this;
    }

    public A removeFromEnabled(String... items) {
        for (String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
    }

    public A removeAllFromEnabled(Collection<String> items) {
        for (String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
    }

    public List<String> getEnabled() {
        return this.enabled;
    }

    public String getEnabled(int index) {
        return this.enabled.get(index);
    }

    public String getFirstEnabled() {
        return this.enabled.get(0);
    }

    public String getLastEnabled() {
        return this.enabled.get(enabled.size() - 1);
    }

    public String getMatchingEnabled(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: enabled) { if(predicate.apply(item)){ return item;} } return null;
    }

    public Boolean hasMatchingEnabled(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: enabled) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withEnabled(List<String> enabled) {
        if (this.enabled != null) { _visitables.get("enabled").removeAll(this.enabled);}
        if (enabled != null) {this.enabled = new ArrayList<String>(); for (String item : enabled){this.addToEnabled(item);}} else { this.enabled = null;} return (A) this;
    }

    public A withEnabled(String... enabled) {
        if (this.enabled != null) {this.enabled.clear();}
        if (enabled != null) {for (String item :enabled){ this.addToEnabled(item);}} return (A) this;
    }

    public Boolean hasEnabled() {
        return enabled != null && !enabled.isEmpty();
    }

    public A addNewEnabled(String arg1) {
        return (A)addToEnabled(new String(arg1));
    }

    public A addNewEnabled(StringBuilder arg1) {
        return (A)addToEnabled(new String(arg1));
    }

    public A addNewEnabled(StringBuffer arg1) {
        return (A)addToEnabled(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        CustomFeatureGatesFluentImpl that = (CustomFeatureGatesFluentImpl) o;
        if (disabled != null ? !disabled.equals(that.disabled) :that.disabled != null) return false;
        if (enabled != null ? !enabled.equals(that.enabled) :that.enabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(disabled,  enabled,  super.hashCode());
    }

}

==> openshift-model-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/CustomFeatureGatesFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class CustomFeatureGatesFluentImpl<A extends CustomFeatureGatesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements CustomFeatureGatesFluent<A> {

    private List<String> disabled = new ArrayList<String>();
    private List<String> enabled = new ArrayList<String>();

    public CustomFeatureGatesFluentImpl() {
    }

    public CustomFeatureGatesFluentImpl(CustomFeatureGates instance) {
        this.withDisabled(instance.getDisabled()); 
        this.withEnabled(instance.getEnabled()); 
    }

    public A addToDisabled(int index,String item) {
        if (this.disabled == null) {this.disabled = new ArrayList<String>();}
        this.disabled.add(index, item);
        return (A)this;
    }

    public A setToDisabled(int index,String item) {
        if (this.disabled == null) {this.disabled = new ArrayList<String>();}
        this.disabled.set(index, item); return (A)this;
    }

    public A addToDisabled(String... items) {
        if (this.disabled == null) {this.disabled = new ArrayList<String>();}
        for (String item : items) {this.disabled.add(item);} return (A)this;
    }

    public A addAllToDisabled(Collection<String> items) {
        if (this.disabled == null) {this.disabled = new ArrayList<String>();}
        for (String item : items) {this.disabled.add(item);} return (A)this;
    }

    public A removeFromDisabled(String... items) {
        for (String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
    }

    public A removeAllFromDisabled(Collection<String> items) {
        for (String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
    }

    public List<String> getDisabled() {
        return this.disabled;
    }

    public String getDisabled(int index) {
        return this.disabled.get(index);
    }

    public String getFirstDisabled() {
        return this.disabled.get(0);
    }

    public String getLastDisabled() {
        return this.disabled.get(disabled.size() - 1);
    }

    public String getMatchingDisabled(Predicate<String> predicate) {
        for (String item: disabled) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingDisabled(Predicate<String> predicate) {
        for (String item: disabled) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withDisabled(List<String> disabled) {
        if (this.disabled != null) { _visitables.get("disabled").removeAll(this.disabled);}
        if (disabled != null) {this.disabled = new ArrayList<String>(); for (String item : disabled){this.addToDisabled(item);}} else { this.disabled = null;} return (A) this;
    }

    public A withDisabled(String... disabled) {
        if (this.disabled != null) {this.disabled.clear();}
        if (disabled != null) {for (String item :disabled){ this.addToDisabled(item);}} return (A) this;
    }

    public Boolean hasDisabled() {
        return disabled != null && !disabled.isEmpty();
    }

    public A addNewDisabled(String arg1) {
        return (A)addToDisabled(new String(arg1));
    }

    public A addNewDisabled(StringBuilder arg1) {
        return (A)addToDisabled(new String(arg1));
    }

    public A addNewDisabled(StringBuffer arg1) {
        return (A)addToDisabled(new String(arg1));
    }

    public A addToEnabled(int index,String item) {
        if (this.enabled == null) {this.enabled = new ArrayList<String>();}
        this.enabled.add(index, item);
        return (A)this;
    }

    public A setToEnabled(int index,String item) {
        if (this.enabled == null) {this.enabled = new ArrayList<String>();}
        this.enabled.set(index, item); return (A)this;
    }

    public A addToEnabled(String... items) {
        if (this.enabled == null) {this.enabled = new ArrayList<String>();}
        for (String item : items) {this.enabled.add(item);} return (A)this;
    }

    public A addAllToEnabled(Collection<String> items) {
        if (this.enabled == null) {this.enabled = new ArrayList<String>();}
        for (String item : items) {this.enabled.add(item);} return (A)this;
    }

    public A removeFromEnabled(String... items) {
        for (String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
    }

    public A removeAllFromEnabled(Collection<String> items) {
        for (String item : items) {if (this.enabled!= null){ this.enabled.remove(item);}} return (A)this;
    }

    public List<String> getEnabled() {
        return this.enabled;
    }

    public String getEnabled(int index) {
        return this.enabled.get(index);
    }

    public String getFirstEnabled() {
        return this.enabled.get(0);
    }

    public String getLastEnabled() {
        return this.enabled.get(enabled.size() - 1);
    }

    public String getMatchingEnabled(Predicate<String> predicate) {
        for (String item: enabled) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingEnabled(Predicate<String> predicate) {
        for (String item: enabled) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withEnabled(List<String> enabled) {
        if (this.enabled != null) { _visitables.get("enabled").removeAll(this.enabled);}
        if (enabled != null) {this.enabled = new ArrayList<String>(); for (String item : enabled){this.addToEnabled(item);}} else { this.enabled = null;} return (A) this;
    }

    public A withEnabled(String... enabled) {
        if (this.enabled != null) {this.enabled.clear();}
        if (enabled != null) {for (String item :enabled){ this.addToEnabled(item);}} return (A) this;
    }

    public Boolean hasEnabled() {
        return enabled != null && !enabled.isEmpty();
    }

    public A addNewEnabled(String arg1) {
        return (A)addToEnabled(new String(arg1));
    }

    public A addNewEnabled(StringBuilder arg1) {
        return (A)addToEnabled(new String(arg1));
    }

    public A addNewEnabled(StringBuffer arg1) {
        return (A)addToEnabled(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        CustomFeatureGatesFluentImpl that = (CustomFeatureGatesFluentImpl) o;
        if (disabled != null ? !disabled.equals(that.disabled) :that.disabled != null) return false;
        if (enabled != null ? !enabled.equals(that.enabled) :that.enabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(disabled,  enabled,  super.hashCode());
    }

}
